==> ubicoders-vrobots-0.3.2.tar.gz: ubicoders-vrobots-0.3.2/src/ubicoders_vrobots/vrobots_bridge/ws_utils.py <==
from ubicoders_vrobots.vrobots_msgs.python.srv_omr_walls_generated import (
    SrvOMRWall,
    SrvOMRWallT,
)
from ..vrobots_msgs.python.states_generated import StatesMsg
from ..vrobots_msgs.python.empty_generated import EmptyMsg
from ..vrobots_msgs.python.commands_generated import CommandMsg


class WebSocketList(list):
    def __init__(self, *args):
        super().__init__(args)


WSList = WebSocketList()


class NamedWebsocket:
    def __init__(self, name, ws) -> None:
        self.ws = ws
        self.name = name

    async def handle_new_msg(self, name, ws):
        if name is None or self.name != name:
            return
        await self.handle_dup(ws)

    async def handle_dup(self, ws):
        if self.validate_dup(ws) is True:
            return
        else:
            await self.ws.close()
            self.ws = ws

    def validate_dup(self, ws):
        if self.ws is ws:
            return True
        else:
            return False

    def remove(self):
        print(f"Removing {self.name} from ws_list")
        WSList.remove(self)


async def upsert_ws_list(name, ws):
    # check if ws_list has name
    for named_ws in WSList:
        if named_ws.name == name:
            await named_ws.handle_new_msg(name, ws)
            return

    # if new, push
    print(f"{name} connected.")
    named_ws = NamedWebsocket(name, ws)
    WSList.append(named_ws)
    await named_ws.handle_new_msg(name, ws)


def remove_ws_list(name):
    for named_ws in WSList:
        if named_ws.name == name:
            print(f"{name} disconnected.")
            named_ws.remove()
            return


def get_name_from_msg(msg):

    if StatesMsg.StatesMsgBufferHasIdentifier(msg, 0) is True:
        robots_all = StatesMsg.GetRootAsStatesMsg(msg)
        if robots_all == None or robots_all.Name() == None:
            return "unregistered"
        name = robots_all.Name().decode("utf-8")
        return name

    if CommandMsg.CommandMsgBufferHasIdentifier(msg, 0) is True:
        cmd = CommandMsg.GetRootAsCommandMsg(msg)
        if robots_all == None or robots_all.Name() == None:
            return "unregistered"
        name = cmd.Name().decode("utf-8")
        return name

    if SrvOMRWall.SrvOMRWallBufferHasIdentifier(msg, 0) is True:
        srv_omr_wall = SrvOMRWall.GetRootAsSrvOMRWall(msg)
        if robots_all == None or robots_all.Name() == None:
            return "unregistered"
        name = srv_omr_wall.Name().decode("utf-8")
        return name

    return None

==> ubicoders-vrobots-0.3.3.tar.gz: ubicoders-vrobots-0.3.3/src/ubicoders_vrobots/vrobots_bridge/ws_utils.py <==
from ubicoders_vrobots.vrobots_msgs.python.srv_omr_walls_generated import (
    SrvOMRWall,
    SrvOMRWallT,
)
from ..vrobots_msgs.python.states_generated import StatesMsg
from ..vrobots_msgs.python.empty_generated import EmptyMsg
from ..vrobots_msgs.python.commands_generated import CommandMsg


class WebSocketList(list):
    def __init__(self, *args):
        super().__init__(args)


WSList = WebSocketList()


class NamedWebsocket:
    def __init__(self, name, ws) -> None:
        self.ws = ws
        self.name = name

    def handle_new_msg(self, name, ws):
        if name is None or self.name != name:
            return
        self.handle_dup(ws)

    def handle_dup(self, ws):
        if self.validate_dup(ws) is True:
            return
        else:
            self.ws.close()
            self.ws = ws

    def validate_dup(self, ws):
        if self.ws is ws:
            return True
        else:
            return False

    def remove(self):
        print(f"Removing {self.name} from ws_list")
        WSList.remove(self)


def upsert_ws_list(name, ws):
    # check if ws_list has name
    for named_ws in WSList:
        if named_ws.name == name:
            named_ws.handle_new_msg(name, ws)
            return

    # if new, push
    print(f"{name} connected.")
    named_ws = NamedWebsocket(name, ws)
    WSList.append(named_ws)
    named_ws.handle_new_msg(name, ws)


def remove_ws_list(name):
    for named_ws in WSList:
        if named_ws.name == name:
            print(f"{name} disconnected.")
            named_ws.remove()
            return


def get_name_from_msg(msg):
    if StatesMsg.StatesMsgBufferHasIdentifier(msg, 0) is True:
        robots_all = StatesMsg.GetRootAsStatesMsg(msg)
        if robots_all == None or robots_all.Name() == None:
            return "unregistered"
        name = robots_all.Name().decode("utf-8")
        return name

    if CommandMsg.CommandMsgBufferHasIdentifier(msg, 0) is True:
        robots_all = CommandMsg.GetRootAsCommandMsg(msg)
        if robots_all == None or robots_all.Name() == None:
            return "unregistered"
        name = robots_all.Name().decode("utf-8")
        return name

    if SrvOMRWall.SrvOMRWallBufferHasIdentifier(msg, 0) is True:
        robots_all = SrvOMRWall.GetRootAsSrvOMRWall(msg)
        if robots_all == None or robots_all.Name() == None:
            return "unregistered"
        name = robots_all.Name().decode("utf-8")
        return name

    return None
